@@ -27,7 +27,7 @@ app = FastAPI()
 class Data(BaseModel):
     data: Json
 
-@app.post(f"/{service_name}")
+@app.post("/")
 def api(input: Data):
     data = input.data
     logging.debug(f"{data=}")
